@@ -6,16 +6,18 @@ import jwt
 from .base import Strategy, get_user
 
 class JWTStrategy(Strategy):
-    def __init__(self, secret, *, cookie = Configuration.default_jwt_cookie, expiry = None):
+    def __init__(self, secret, *, expiry = None):
         self._secret = secret
-        self._cookie = cookie
         self._expiry = expiry
 
+    def get_token(self):
+        return request.cookies.get("lonny-jwt")
+
     def authenticate(self, state):
-        if self._cookie not in request.cookies:
+        token = self.get_token()
+        if token is None:
             return
         state.attempted = True
-        token = request.cookies[self._cookie]
         try:
             data = jwt.decode(token, self._secret)
             state.user = self.get_user(data)
@@ -23,8 +25,7 @@ class JWTStrategy(Strategy):
             pass
 
     def grant(self, request):
-        data = self.get_token(get_user())
+        data = self.build_token(get_user())
         if self._expiry is not None:
             data["exp"] = datetime.utcnow() + self._expiry
-        token = jwt.encode(data, self._secret)
-        request.set_cookie(self._cookie, token)
\ No newline at end of file
+        return jwt.encode(data, self._secret)
\ No newline at end of file
